@@ -7,7 +7,7 @@
 
 #include <QDebug>
 
-DummyNotifier::DummyNotifier(QObject* parent)
+DummyNotifier::DummyNotifier(QObject *parent)
     : BackendNotifierModule(parent)
 {
 }
@@ -18,6 +18,5 @@ DummyNotifier::~DummyNotifier()
 
 void DummyNotifier::recheckSystemUpdateNeeded()
 {
-    emit foundUpdates();
+    Q_EMIT foundUpdates();
 }
-
