@@ -17,6 +17,7 @@
 #include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTest>
+#include <flatpak.h>
 
 class FlatpakTest : public QObject
 {
@@ -81,6 +82,38 @@ private Q_SLOTS:
         QVERIFY(resources.count() > 0);
     }
 
+    void testFlatpakrefWithoutExistingRemote()
+    {
+        // Remove the automatically added source again!
+        auto sourcesModel = SourcesModel::global();
+        QVERIFY(sourcesModel);
+        auto sourcesBackend = sourcesModel->index(0, 0).data(SourcesModel::SourcesBackend).value<AbstractSourcesBackend *>();
+        QVERIFY(sourcesBackend);
+        auto sources = sourcesBackend->sources();
+        QVERIFY(sources);
+        for (auto i = sources->rowCount() - 1; i >= 0; --i) {
+            QSignalSpy spy(sources, &QAbstractItemModel::rowsRemoved);
+            const auto id = sources->index(i, 0).data(AbstractSourcesBackend::IdRole).toString();
+            QVERIFY(sourcesBackend->removeSource(id));
+            QVERIFY(spy.count() >= 1 || spy.wait());
+        }
+        // NOTE: there will be a stub entry in the model now, don't assume it to be rowCount==0!
+
+        AbstractResourcesBackend::Filters f;
+        f.resourceUrl = QUrl(QStringLiteral("https://dl.flathub.org/repo/appstream/com.dosbox.DOSBox.flatpakref"));
+        const auto res = getResources(m_appBackend->search(f));
+        QCOMPARE(res.count(), 1);
+
+        const auto ourResource = res.constFirst();
+        QCOMPARE(ourResource->state(), AbstractResource::None);
+        QCOMPARE(waitTransaction(m_appBackend->installApplication(ourResource)), Transaction::DoneStatus);
+        QCOMPARE(ourResource->state(), AbstractResource::Installed);
+        f.resourceUrl = QUrl(QStringLiteral("flatpak:app/com.dosbox.DOSBox/") + QLatin1StringView(flatpak_get_default_arch()) + QStringLiteral("/stable"));
+        QCOMPARE(getResources(m_appBackend->search(f)).count(), 1);
+        QCOMPARE(waitTransaction(m_appBackend->removeApplication(ourResource)), Transaction::DoneStatus);
+        QCOMPARE(ourResource->state(), AbstractResource::None);
+    }
+
     void testInstallApp()
     {
         AbstractResourcesBackend::Filters f;
@@ -92,6 +125,8 @@ private Q_SLOTS:
         QCOMPARE(ourResource->state(), AbstractResource::None);
         QCOMPARE(waitTransaction(m_appBackend->installApplication(ourResource)), Transaction::DoneStatus);
         QCOMPARE(ourResource->state(), AbstractResource::Installed);
+        f.resourceUrl = QUrl(QStringLiteral("flatpak:app/com.dosbox.DOSBox/") + QLatin1StringView(flatpak_get_default_arch()) + QStringLiteral("/stable"));
+        QCOMPARE(getResources(m_appBackend->search(f)).count(), 1);
         QCOMPARE(waitTransaction(m_appBackend->removeApplication(ourResource)), Transaction::DoneStatus);
         QCOMPARE(ourResource->state(), AbstractResource::None);
     }
@@ -106,6 +141,18 @@ private Q_SLOTS:
         f.resourceUrl = QUrl(QStringLiteral("appstream://dosbox.desktop"));
         const auto res2 = getResources(m_appBackend->search(f));
         QCOMPARE(res2, res);
+    }
+
+    void testSearches()
+    {
+        AbstractResourcesBackend::Filters f;
+        f.resourceUrl = QUrl(QStringLiteral("flatpak:app/com.dosbox.DOSBox/") + QLatin1StringView(flatpak_get_default_arch()) + QStringLiteral("/stable"));
+        const auto res = getResources(m_appBackend->search(f));
+        QCOMPARE(res.count(), 1);
+
+        f.resourceUrl = QUrl(QStringLiteral("appstream://dosbox.desktop"));
+        const auto res2 = getResources(m_appBackend->search(f));
+        QCOMPARE(res2, res);
 
         f.resourceUrl = QUrl(QStringLiteral("appstream://com.dosbox.DOSBox.desktop"));
         const auto res3 = getResources(m_appBackend->search(f));
